Computes the item Fisher Information given an ability level based on the GRM model
Fisher_GRM(theta_est, item_par, nres)ability level
vector containing the item parameters. First component
is the alpha parameter and the next are the beta parameters
number of possible item responses
An integer that represents the Fisher Information value of the specified item given the ability level